CREPEvaluator | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

# Class CREPEvaluator

- Defined in packages/crep-engine/CREPEvaluator.ts:7

#####
Index

### Constructors

constructor

### Properties

manager

### Methods

evaluateNewDataPoint

## Constructors

### constructor

- new CREPEvaluator(manager): CREPEvaluator

- #### Parameters

  - manager: CREPManager

  #### Returns CREPEvaluator

  - Defined in packages/crep-engine/CREPEvaluator.ts:8

## Properties

### `Private` manager

manager: CREPManager

- Defined in packages/crep-engine/CREPEvaluator.ts:8

## Methods

### evaluateNewDataPoint

- evaluateNewDataPoint(data): void

- #### Parameters

  - data: {
    C: number;
    E: number;
    P: number;
    R: number;
    }

    - ##### C: number

    - ##### E: number

    - ##### P: number

    - ##### R: number

  #### Returns void

  - Defined in packages/crep-engine/CREPEvaluator.ts:10